==> sts-spring-0.26.4-sources.jar: de/adorsys/sts/keyrotation/KeyRotationSchedule.java <==
package de.adorsys.sts.keyrotation;

import de.adorsys.lockpersistence.client.LockClient;
import de.adorsys.sts.keymanagement.model.StsKeyStore;
import de.adorsys.sts.keymanagement.persistence.KeyStoreRepository;
import de.adorsys.sts.keymanagement.service.KeyManagementProperties;
import de.adorsys.sts.keymanagement.service.KeyRotationService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.time.Clock;
import java.time.ZoneOffset;
import java.time.ZonedDateTime;
import java.util.List;
import java.util.stream.Collectors;

@Component
public class KeyRotationSchedule {
    private final static Logger LOG = LoggerFactory.getLogger(KeyRotationSchedule.class);

    private final KeyRotationService keyRotationService;
    private final KeyStoreRepository keyStoreRepository;

    private final LockClient lockClient;

    private final String rotationLockName;

    private final Clock clock;

    @Autowired
    public KeyRotationSchedule(
            KeyRotationService keyRotationService,
            @Qualifier("cached") KeyStoreRepository keyStoreRepository,
            LockClient lockClient,
            KeyManagementProperties properties,
            Clock clock
    ) {
        this.keyRotationService = keyRotationService;
        this.keyStoreRepository = keyStoreRepository;
        this.lockClient = lockClient;
        this.clock = clock;

        String keyStoreName = properties.getKeystore().getName();
        this.rotationLockName = "key-rotation -- " + keyStoreName;
    }

    @Scheduled(
            initialDelayString = "${sts.keymanagement.rotation.check-interval:60000}",
            fixedDelayString = "${sts.keymanagement.rotation.check-interval:60000}"
    )
    public void scheduledRotation() {

        lockClient.executeIfOwned(rotationLockName, () -> {
            if(keyStoreRepository.exists()) {
                LOG.debug("Perform key rotation...");

                performKeyRotation();

                LOG.debug("Key rotation finished.");
            } else {
                LOG.debug("No key rotation needed. Keystore repository is (still) empty.");
            }
        });
    }

    private void performKeyRotation() {
        StsKeyStore keyStore = keyStoreRepository.load();
        KeyRotationService.KeyRotationResult keyRotationResult = keyRotationService.rotate(keyStore);

        List<String> removedKeys = keyRotationResult.getRemovedKeys();
        List<String> futureKeys = keyRotationResult.getFutureKeys();
        List<String> generatedKeys = keyRotationResult.getGeneratedKeys();

        if(LOG.isDebugEnabled()) {
            LOG.debug(removedKeys.size() + " keys removed: [" + removedKeys.stream().collect(Collectors.joining(",")) + "]");
            LOG.debug(futureKeys.size() + " future keys generated: [" + futureKeys.stream().collect(Collectors.joining(",")) + "]");
            LOG.debug(generatedKeys.size() + " keys generated: [" + generatedKeys.stream().collect(Collectors.joining(",")) + "]");
        }

        if(removedKeys.size() + futureKeys.size() + generatedKeys.size() > 0) {
            keyStore.setLastUpdate(now());
            keyStoreRepository.save(keyStore);
        }
    }

    private ZonedDateTime now() {
        return clock.instant().atZone(ZoneOffset.UTC);
    }
}

==> sts-spring-0.29.8-sources.jar: de/adorsys/sts/keyrotation/KeyRotationSchedule.java <==
package de.adorsys.sts.keyrotation;

import de.adorsys.lockpersistence.client.LockClient;
import de.adorsys.sts.keymanagement.model.StsKeyStore;
import de.adorsys.sts.keymanagement.persistence.KeyStoreRepository;
import de.adorsys.sts.keymanagement.service.KeyManagementProperties;
import de.adorsys.sts.keymanagement.service.KeyRotationService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.time.Clock;
import java.time.ZoneOffset;
import java.time.ZonedDateTime;
import java.util.List;
import java.util.stream.Collectors;

@Component
public class KeyRotationSchedule {
    private static final Logger LOG = LoggerFactory.getLogger(KeyRotationSchedule.class);

    private final KeyRotationService keyRotationService;
    private final KeyStoreRepository keyStoreRepository;

    private final LockClient lockClient;

    private final String rotationLockName;

    private final Clock clock;

    @Autowired
    public KeyRotationSchedule(
            KeyRotationService keyRotationService,
            @Qualifier("cached") KeyStoreRepository keyStoreRepository,
            LockClient lockClient,
            KeyManagementProperties properties,
            Clock clock
    ) {
        this.keyRotationService = keyRotationService;
        this.keyStoreRepository = keyStoreRepository;
        this.lockClient = lockClient;
        this.clock = clock;

        String keyStoreName = properties.getKeystore().getName();
        this.rotationLockName = "key-rotation -- " + keyStoreName;
    }

    @Scheduled(
            initialDelayString = "${sts.keymanagement.rotation.check-interval:60000}",
            fixedDelayString = "${sts.keymanagement.rotation.check-interval:60000}"
    )
    public void scheduledRotation() {

        lockClient.executeIfOwned(rotationLockName, () -> {
            if(keyStoreRepository.exists()) {
                LOG.debug("Perform key rotation...");

                performKeyRotation();

                LOG.debug("Key rotation finished.");
            } else {
                LOG.debug("No key rotation needed. Keystore repository is (still) empty.");
            }
        });
    }

    private void performKeyRotation() {
        StsKeyStore keyStore = keyStoreRepository.load();
        KeyRotationService.KeyRotationResult keyRotationResult = keyRotationService.rotate(keyStore);

        List<String> removedKeys = keyRotationResult.getRemovedKeys();
        List<String> futureKeys = keyRotationResult.getFutureKeys();
        List<String> generatedKeys = keyRotationResult.getGeneratedKeys();

        if(LOG.isDebugEnabled()) {
            LOG.debug(removedKeys.size() + " keys removed: [" + removedKeys.stream().collect(Collectors.joining(",")) + "]");
            LOG.debug(futureKeys.size() + " future keys generated: [" + futureKeys.stream().collect(Collectors.joining(",")) + "]");
            LOG.debug(generatedKeys.size() + " keys generated: [" + generatedKeys.stream().collect(Collectors.joining(",")) + "]");
        }

        if(removedKeys.size() + futureKeys.size() + generatedKeys.size() > 0) {
            keyStore.setLastUpdate(now());
            keyStoreRepository.save(keyStore);
        }
    }

    private ZonedDateTime now() {
        return clock.instant().atZone(ZoneOffset.UTC);
    }
}
